==> 1.0.5.tar.gz: android/src/main/java/com/aruistar/flutter/plugin/flutter_nfc_mifare/FlutterNfcMifarePlugin.java <==
package com.aruistar.flutter.plugin.flutter_nfc_mifare;

import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.nfc.NfcAdapter;
import android.nfc.Tag;
import android.nfc.tech.MifareClassic;
import android.util.Log;
import android.widget.Toast;
import android.app.Activity;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;

import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.concurrent.ExecutionException;

/**
 * FlutterNfcMifarePlugin
 */
public class FlutterNfcMifarePlugin implements FlutterPlugin, ActivityAware , MethodCallHandler/*, PluginRegistry.NewIntentListener*/ {

    private static NfcAdapter mNfcAdapter;
    private static PendingIntent mPendingIntent;
    private static Activity activity;
    private static Context context;
    static MethodChannel channel = null;
    static MifareClassic currentMF1 = null;
    private static FlutterNfcMifarePlugin pluginbk;
    /**
     * Plugin registration.
     */

     public void onAttachedToEngine(@NonNull FlutterPluginBinding binding) {
        channel = new MethodChannel(binding.binaryMessenger(), "flutter_nfc_mifare");
        FlutterNfcMifarePlugin plugin = new FlutterNfcMifarePlugin();
        channel.setMethodCallHandler(plugin);

        context = binding.getApplicationContext();

        pluginbk = plugin;
        // initialize nfc stuff
        mNfcAdapter = NfcAdapter.getDefaultAdapter(context);
        if (mNfcAdapter == null) {
            // Stop here, we need NFC
            Toast.makeText(context, "对不起，您的设备不支持NFC，无法正常使用本软件",
                    Toast.LENGTH_LONG).show();
        } else if (!mNfcAdapter.isEnabled()) {
            Toast.makeText(context, "请到系统设置，开启NFC功能", Toast.LENGTH_LONG).show();
        }
      }

      public void onDetachedFromEngine(FlutterPlugin.FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
      }
    
      public void onAttachedToActivity(ActivityPluginBinding binding) {
        activity = binding.activity();
      }
    
      public void onDetachedFromActivity() {
        // no op
      }
    
      public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding ) {
        activity = binding.activity();
      }
    
      public void onDetachedFromActivityForConfigChanges() {
        // no op
      }


    @Override
    public void onMethodCall(MethodCall call, Result result) {
        if (call.method.equals("readMF1")) {
            List arguments = (List) call.arguments;
            result.success(readMF1((int) arguments.get(0), (int) arguments.get(1), (byte[]) arguments.get(2)));
        } else if (call.method.equals("writeMF1")) {
            List arguments = (List) call.arguments;
            result.success(writeMF1((int) arguments.get(0), (int) arguments.get(1), (byte[]) arguments.get(2), (byte[]) arguments.get(3)));
        } else if (call.method.equals("isMF1Here")) {
            if (currentMF1 == null) {
                result.success(false);
                return;
            }

            try {
                currentMF1.connect();
                currentMF1.close();
                result.success(true);
            } catch (IOException e) {
                e.printStackTrace();
                currentMF1 = null;
                result.success(false);
            }
        } else if (call.method.equals("habilitar")) {
          
        mNfcAdapter.enableReaderMode(activity,new NfcAdapter.ReaderCallback () {
          @Override
          public void onTagDiscovered(Tag tag) {
            System.out.println("Fuck You");
            byte[] MF1_UID = tag.getId();
            log(MF1_UID);
            MifareClassic mfc = MifareClassic.get(tag);
            if (mfc == null) return;
            System.out.println(tag);
            currentMF1 = mfc;
            System.out.println(currentMF1);
            try {
            currentMF1.connect();
            boolean isWhite = mfc.authenticateSectorWithKeyA(2, MifareClassic.KEY_DEFAULT);
            int blockCount = mfc.getBlockCount();
            int sectorCount = mfc.getSectorCount();
            currentMF1.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
          }
        } , 1, null);
            result.success(true);
        } else if (call.method.equals("deshabilitar")) {
            mNfcAdapter.disableReaderMode(activity);
            result.success(true);
        } else {
            result.notImplemented();
        }
    }


    private static void log(String str) {
        Log.e("ttt", str);
    }

    private static void log(byte[] bytes) {
        String str = "";
        for (int i = 0; i < bytes.length; i++) {
            str += bytes[i];
            str += ",";
        }

        log(str);
    }

    private boolean writeMF1(int sectorIndex, int blockIndex, byte[] key, byte[] data) {
        MifareClassic mfc = currentMF1;
        try {
            mfc.connect();
            boolean isOpen = mfc.authenticateSectorWithKeyA(sectorIndex, key);
            if (isOpen) {
                mfc.writeBlock(mfc.sectorToBlock(sectorIndex) + blockIndex, data);
                return true;
            } else {
                return false;
            }
        } catch (IOException e) {
            e.printStackTrace();
            return false;
        } finally {
            try {
                mfc.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

    }

    private byte[] readMF1(int sectorIndex, int blockIndex, byte[] key) {
        MifareClassic mfc = currentMF1;
        try {
            mfc.connect();
            boolean isOpen = mfc.authenticateSectorWithKeyA(sectorIndex, key);
            log("is OPen" + isOpen);
            if (isOpen) {
                return mfc.readBlock(mfc.sectorToBlock(sectorIndex) + blockIndex);
            } else {
                return null;
            }
        } catch (IOException e) {
            e.printStackTrace();
            return null;
        } finally {
            try {
                mfc.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

    }

    public void iamhere(HashMap map) {
        channel.invokeMethod("iamhere", map, new Result() {
            @Override
            public void success(Object o) {
                log("success");
            }

            @Override
            public void error(String s, String s1, Object o) {
                log("error");
            }

            @Override
            public void notImplemented() {
                log("notImplemented");
            }
        });
    }


    private boolean testKey(MifareClassic mfc, byte[] key) throws IOException {
        return mfc.authenticateSectorWithKeyA(2, key);
    }

    private byte[] getKeyByUID(byte[] MF1_UID) {
        byte[] key = new byte[6];

        key[0] = (byte) (0x81 ^ MF1_UID[0] ^ MF1_UID[2]);
        key[1] = (byte) (0xED ^ MF1_UID[1] ^ MF1_UID[3]);
        key[2] = (byte) (0xBF ^ MF1_UID[0] ^ MF1_UID[2]);
        key[3] = (byte) (0xE8 ^ MF1_UID[1] ^ MF1_UID[3]);
        key[4] = (byte) (0xA5 ^ MF1_UID[0] ^ MF1_UID[2]);
        key[5] = (byte) (0xFC ^ MF1_UID[1] ^ MF1_UID[3]);

        return key;
    }
}

==> 1.0.7.tar.gz: android/src/main/java/com/aruistar/flutter/plugin/flutter_nfc_mifare/FlutterNfcMifarePlugin.java <==
package com.aruistar.flutter.plugin.flutter_nfc_mifare;

import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.nfc.NfcAdapter;
import android.nfc.Tag;
import android.nfc.tech.MifareClassic;
import android.util.Log;
import android.widget.Toast;
import android.app.Activity;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;

import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.concurrent.ExecutionException;

/**
 * FlutterNfcMifarePlugin
 */
public class FlutterNfcMifarePlugin implements FlutterPlugin, ActivityAware , MethodCallHandler/*, PluginRegistry.NewIntentListener*/ {

    private static NfcAdapter mNfcAdapter;
    private static PendingIntent mPendingIntent;
    private ActivityPluginBinding activity;
    private FlutterPluginBinding _flutterBinding;
    private MethodChannel channel;
    static MifareClassic currentMF1 = null;
    private static FlutterNfcMifarePlugin pluginbk;
    /**
     * Plugin registration.
     */

    @Override
     public void onAttachedToEngine(FlutterPluginBinding binding) {
        channel = new MethodChannel(binding.getFlutterEngine().getDartExecutor(), "flutter_nfc_mifare");
        FlutterNfcMifarePlugin plugin = new FlutterNfcMifarePlugin();
        channel.setMethodCallHandler(plugin);

        context = binding.getApplicationContext();

        pluginbk = plugin;
        // initialize nfc stuff
        mNfcAdapter = NfcAdapter.getDefaultAdapter(context);
        if (mNfcAdapter == null) {
            // Stop here, we need NFC
            Toast.makeText(context, "对不起，您的设备不支持NFC，无法正常使用本软件",
                    Toast.LENGTH_LONG).show();
        } else if (!mNfcAdapter.isEnabled()) {
            Toast.makeText(context, "请到系统设置，开启NFC功能", Toast.LENGTH_LONG).show();
        }
      }


      @Override
      public void onDetachedFromEngine(FlutterPlugin.FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
      }
    
      @Override
      public void onAttachedToActivity(ActivityPluginBinding binding) {
        activity = binding;
      }
    
      @Override
      public void onDetachedFromActivity() {
        // no op
      }
    
      @Override
      public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding ) {
        activity = binding;
      }
    
      @Override
      public void onDetachedFromActivityForConfigChanges() {
        // no op
      }


    @Override
    public void onMethodCall(MethodCall call, Result result) {
        if (call.method.equals("readMF1")) {
            List arguments = (List) call.arguments;
            result.success(readMF1((int) arguments.get(0), (int) arguments.get(1), (byte[]) arguments.get(2)));
        } else if (call.method.equals("writeMF1")) {
            List arguments = (List) call.arguments;
            result.success(writeMF1((int) arguments.get(0), (int) arguments.get(1), (byte[]) arguments.get(2), (byte[]) arguments.get(3)));
        } else if (call.method.equals("isMF1Here")) {
            if (currentMF1 == null) {
                result.success(false);
                return;
            }

            try {
                currentMF1.connect();
                currentMF1.close();
                result.success(true);
            } catch (IOException e) {
                e.printStackTrace();
                currentMF1 = null;
                result.success(false);
            }
        } else if (call.method.equals("habilitar")) {
          
        mNfcAdapter.enableReaderMode(activity,new NfcAdapter.ReaderCallback () {
          @Override
          public void onTagDiscovered(Tag tag) {
            System.out.println("Fuck You");
            byte[] MF1_UID = tag.getId();
            log(MF1_UID);
            MifareClassic mfc = MifareClassic.get(tag);
            if (mfc == null) return;
            System.out.println(tag);
            currentMF1 = mfc;
            System.out.println(currentMF1);
            try {
            currentMF1.connect();
            boolean isWhite = mfc.authenticateSectorWithKeyA(2, MifareClassic.KEY_DEFAULT);
            int blockCount = mfc.getBlockCount();
            int sectorCount = mfc.getSectorCount();
            currentMF1.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
          }
        } , 1, null);
            result.success(true);
        } else if (call.method.equals("deshabilitar")) {
            mNfcAdapter.disableReaderMode(activity);
            result.success(true);
        } else {
            result.notImplemented();
        }
    }


    private static void log(String str) {
        Log.e("ttt", str);
    }

    private static void log(byte[] bytes) {
        String str = "";
        for (int i = 0; i < bytes.length; i++) {
            str += bytes[i];
            str += ",";
        }

        log(str);
    }

    private boolean writeMF1(int sectorIndex, int blockIndex, byte[] key, byte[] data) {
        MifareClassic mfc = currentMF1;
        try {
            mfc.connect();
            boolean isOpen = mfc.authenticateSectorWithKeyA(sectorIndex, key);
            if (isOpen) {
                mfc.writeBlock(mfc.sectorToBlock(sectorIndex) + blockIndex, data);
                return true;
            } else {
                return false;
            }
        } catch (IOException e) {
            e.printStackTrace();
            return false;
        } finally {
            try {
                mfc.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

    }

    private byte[] readMF1(int sectorIndex, int blockIndex, byte[] key) {
        MifareClassic mfc = currentMF1;
        try {
            mfc.connect();
            boolean isOpen = mfc.authenticateSectorWithKeyA(sectorIndex, key);
            log("is OPen" + isOpen);
            if (isOpen) {
                return mfc.readBlock(mfc.sectorToBlock(sectorIndex) + blockIndex);
            } else {
                return null;
            }
        } catch (IOException e) {
            e.printStackTrace();
            return null;
        } finally {
            try {
                mfc.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

    }

    public void iamhere(HashMap map) {
        channel.invokeMethod("iamhere", map, new Result() {
            @Override
            public void success(Object o) {
                log("success");
            }

            @Override
            public void error(String s, String s1, Object o) {
                log("error");
            }

            @Override
            public void notImplemented() {
                log("notImplemented");
            }
        });
    }


    private boolean testKey(MifareClassic mfc, byte[] key) throws IOException {
        return mfc.authenticateSectorWithKeyA(2, key);
    }

    private byte[] getKeyByUID(byte[] MF1_UID) {
        byte[] key = new byte[6];

        key[0] = (byte) (0x81 ^ MF1_UID[0] ^ MF1_UID[2]);
        key[1] = (byte) (0xED ^ MF1_UID[1] ^ MF1_UID[3]);
        key[2] = (byte) (0xBF ^ MF1_UID[0] ^ MF1_UID[2]);
        key[3] = (byte) (0xE8 ^ MF1_UID[1] ^ MF1_UID[3]);
        key[4] = (byte) (0xA5 ^ MF1_UID[0] ^ MF1_UID[2]);
        key[5] = (byte) (0xFC ^ MF1_UID[1] ^ MF1_UID[3]);

        return key;
    }
}
